/* auto-generated on Fri  4 Jan 2019 20:12:48 EST. Do not edit! */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/portability.h */
#ifndef SIMDJSON_PORTABILITY_H
#define SIMDJSON_PORTABILITY_H

#if defined(_MSC_VER)
#include <intrin.h>
#else
#include <x86intrin.h>
#endif

#ifdef _MSC_VER
/* Microsoft C/C++-compatible compiler */
#include <intrin.h>
#include <iso646.h>
#include <cstdint>

static inline bool add_overflow(uint64_t value1, uint64_t value2, uint64_t *result) {
	return _addcarry_u64(0, value1, value2, reinterpret_cast<unsigned __int64 *>(result));
}

#  pragma intrinsic(_umul128)
static inline bool mul_overflow(uint64_t value1, uint64_t value2, uint64_t *result) {
	uint64_t high;
	*result = _umul128(value1, value2, &high);
	return high;
}

static inline int trailingzeroes(uint64_t input_num) {
    return _tzcnt_u64(input_num);
}

static inline int leadingzeroes(uint64_t  input_num) {
    return _lzcnt_u64(input_num);
}

static inline int hamming(uint64_t input_num) {
#ifdef _WIN64  // highly recommended!!!
	return (int)__popcnt64(input_num);
#else  // if we must support 32-bit Windows
	return (int)(__popcnt((uint32_t)input_num) +
		__popcnt((uint32_t)(input_num >> 32)));
#endif
}

#else
#include <x86intrin.h>
#include <cstdint>

static inline bool add_overflow(uint64_t  value1, uint64_t  value2, uint64_t *result) {
	return __builtin_uaddll_overflow(value1, value2, (unsigned long long*)result);
}
static inline bool mul_overflow(uint64_t  value1, uint64_t  value2, uint64_t *result) {
	return __builtin_umulll_overflow(value1, value2, (unsigned long long *)result);
}

/* result might be undefined when input_num is zero */
static inline int trailingzeroes(uint64_t input_num) {
	return _tzcnt_u64(input_num);
}

/* result might be undefined when input_num is zero */
static inline int leadingzeroes(uint64_t  input_num) {
	return _lzcnt_u64(input_num);
}

/* result might be undefined when input_num is zero */
static inline int hamming(uint64_t input_num) {
	return _popcnt64(input_num);
}

#endif // _MSC_VER



// portable version of  posix_memalign
static inline void *aligned_malloc(size_t alignment, size_t size) {
	void *p;
#ifdef _MSC_VER
	p = _aligned_malloc(size, alignment);
#elif defined(__MINGW32__) || defined(__MINGW64__)
	p = __mingw_aligned_malloc(size, alignment);
#else
	// somehow, if this is used before including "x86intrin.h", it creates an
	// implicit defined warning.
	if (posix_memalign(&p, alignment, size) != 0) return NULL;
#endif
	return p;
}


#ifndef __clang__
#ifndef _MSC_VER
static __m256i inline _mm256_loadu2_m128i(__m128i const *__addr_hi,
                                          __m128i const *__addr_lo) {
  __m256i __v256 = _mm256_castsi128_si256(_mm_loadu_si128(__addr_lo));
  return _mm256_insertf128_si256(__v256, _mm_loadu_si128(__addr_hi), 1);
}

static inline void _mm256_storeu2_m128i(__m128i *__addr_hi, __m128i *__addr_lo,
                                        __m256i __a) {
  __m128i __v128;

  __v128 = _mm256_castsi256_si128(__a);
  _mm_storeu_si128(__addr_lo, __v128);
  __v128 = _mm256_extractf128_si256(__a, 1);
  _mm_storeu_si128(__addr_hi, __v128);
}
#endif
#endif


static inline void aligned_free(void *memblock) {
    if(memblock == NULL) return;
#ifdef _MSC_VER
    _aligned_free(memblock);
#elif defined(__MINGW32__) || defined(__MINGW64__)
    __mingw_aligned_free(memblock);
#else
    free(memblock);
#endif
}

#endif /* end of include PORTABILITY_H */
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/portability.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/common_defs.h */
#ifndef SIMDJSON_COMMON_DEFS_H
#define SIMDJSON_COMMON_DEFS_H


#include <cassert>

// the input buf should be readable up to buf + SIMDJSON_PADDING
#define SIMDJSON_PADDING  sizeof(__m256i)

#ifndef _MSC_VER
// Implemented using Labels as Values which works in GCC and CLANG (and maybe
// also in Intel's compiler), but won't work in MSVC.
#define SIMDJSON_USE_COMPUTED_GOTO
#endif




// Align to N-byte boundary
#define ROUNDUP_N(a, n) (((a) + ((n)-1)) & ~((n)-1))
#define ROUNDDOWN_N(a, n) ((a) & ~((n)-1))

#define ISALIGNED_N(ptr, n) (((uintptr_t)(ptr) & ((n)-1)) == 0)

#ifdef _MSC_VER


#define really_inline inline
#define never_inline inline

#define UNUSED
#define WARN_UNUSED

#ifndef likely
#define likely(x) x
#endif
#ifndef unlikely
#define unlikely(x) x
#endif

#else

#define really_inline inline __attribute__((always_inline, unused))
#define never_inline inline __attribute__((noinline, unused))

#define UNUSED __attribute__((unused))
#define WARN_UNUSED __attribute__((warn_unused_result))

#ifndef likely
#define likely(x) __builtin_expect(!!(x), 1)
#endif
#ifndef unlikely
#define unlikely(x) __builtin_expect(!!(x), 0)
#endif

#endif  // MSC_VER

#endif // COMMON_DEFS_H
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/common_defs.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/jsoncharutils.h */
#ifndef SIMDJSON_JSONCHARUTILS_H
#define SIMDJSON_JSONCHARUTILS_H


// structural chars here are
// they are { 0x7b } 0x7d : 0x3a [ 0x5b ] 0x5d , 0x2c (and NULL)
// we are also interested in the four whitespace characters
// space 0x20, linefeed 0x0a, horizontal tab 0x09 and carriage return 0x0d

// these are the chars that can follow a true/false/null or number atom
// and nothing else
const uint32_t structural_or_whitespace_negated[256] = {
    0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1,

    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 0, 1, 1,

    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,

    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1};

// return non-zero if not a structural or whitespace char
// zero otherwise
really_inline uint32_t is_not_structural_or_whitespace(uint8_t c) {
  return structural_or_whitespace_negated[c];
}

const uint32_t structural_or_whitespace[256] = {
    1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
    0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0,
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0,
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
    0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

really_inline uint32_t is_structural_or_whitespace(uint8_t c) {
  return structural_or_whitespace[c];
}

const char digittoval[256] = {
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 0,  1,  2,  3,  4,  5,  6,  7,  8,
    9,  -1, -1, -1, -1, -1, -1, -1, 10, 11, 12, 13, 14, 15, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, 10, 11, 12, 13, 14, 15, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1};

// return true if we have a valid hex between 0000 and FFFF
/*inline bool hex_to_u32(const uint8_t *src, uint32_t *res) {
  uint8_t v1 = src[0];
  uint8_t v2 = src[1];
  uint8_t v3 = src[2];
  uint8_t v4 = src[3];
  *res = digittoval[v1] << 12 | digittoval[v2] << 8 | digittoval[v3] << 4 |
         digittoval[v4];
  return (int32_t)(*res) >= 0;
}*/

// returns a value with the highest bit set if it is not valid
uint32_t hex_to_u32_nocheck(const uint8_t *src) {
  uint8_t v1 = src[0];
  uint8_t v2 = src[1];
  uint8_t v3 = src[2];
  uint8_t v4 = src[3];
  return digittoval[v1] << 12 | digittoval[v2] << 8 | digittoval[v3] << 4 |
         digittoval[v4];
}

// given a code point cp, writes to c
// the utf-8 code, outputting the length in
// bytes, if the length is zero, the code point
// is invalid
//
// This can possibly be made faster using pdep
// and clz and table lookups, but JSON documents
// have few escaped code points, and the following
// function looks cheap.
//
// Note: we assume that surrogates are treated separately
//
inline size_t codepoint_to_utf8(uint32_t cp, uint8_t *c) {
  if (cp <= 0x7F) {
    c[0] = cp;
    return 1; // ascii
  } else if (cp <= 0x7FF) {
    c[0] = (cp >> 6) + 192;
    c[1] = (cp & 63) + 128;
    return 2; // universal plane
  //  Surrogates are treated elsewhere...
  //} //else if (0xd800 <= cp && cp <= 0xdfff) {
  //  return 0; // surrogates // could put assert here
  } else if (cp <= 0xFFFF) {
    c[0] = (cp >> 12) + 224;
    c[1] = ((cp >> 6) & 63) + 128;
    c[2] = (cp & 63) + 128;
    return 3;
  } else if (cp <= 0x10FFFF) { // if you know you have a valid code point, this is not needed
    c[0] = (cp >> 18) + 240;
    c[1] = ((cp >> 12) & 63) + 128;
    c[2] = ((cp >> 6) & 63) + 128;
    c[3] = (cp & 63) + 128;
    return 4;
  }
  // will return 0 when the code point was too large.
  return 0; // bad r
}

#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/jsoncharutils.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/jsonformatutils.h */
#ifndef SIMDJSON_JSONFORMATUTILS_H
#define SIMDJSON_JSONFORMATUTILS_H

#include <stdio.h>
#include <iostream>
#include <iomanip>

static inline void print_with_escapes(const unsigned char *src) {
  while (*src) {
    switch (*src) {
    case '\b':
      putchar('\\');
      putchar('b');
      break;
    case '\f':
      putchar('\\');
      putchar('f');
      break;
    case '\n':
      putchar('\\');
      putchar('n');
      break;
    case '\r':
      putchar('\\');
      putchar('r');
      break;
    case '\"':
      putchar('\\');
      putchar('"');
      break;
    case '\t':
      putchar('\\');
      putchar('t');
      break;
    case '\\':
      putchar('\\');
      putchar('\\');
      break;
    default:
      if (*src <= 0x1F) {
        printf("\\u%04x", *src);
      } else
        putchar(*src);
    }
    src++;
  }
}

static inline void print_with_escapes(const unsigned char *src, std::ostream &os) {
  while (*src) {
    switch (*src) {
    case '\b':
      os << '\\';
      os << 'b';
      break;
    case '\f':
      os << '\\';
      os << 'f';
      break;
    case '\n':
      os << '\\';
      os << 'n';
      break;
    case '\r':
      os << '\\';
      os << 'r';
      break;
    case '\"':
      os << '\\';
      os << '"';
      break;
    case '\t':
      os << '\\';
      os << 't';
      break;
    case '\\':
      os << '\\';
      os << '\\';
      break;
    default:
      if (*src <= 0x1F) {
        std::ios::fmtflags f(os.flags());
        os << std::hex << std::setw(4) << std::setfill('0') << (int) *src;
        os.flags(f);
      } else
        os << *src;
    }
    src++;
  }
}

static inline void print_with_escapes(const char *src, std::ostream &os) {
  print_with_escapes((const unsigned char *)src, os);
}

#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/jsonformatutils.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/jsonioutil.h */
#ifndef SIMDJSON_JSONIOUTIL_H
#define SIMDJSON_JSONIOUTIL_H

#include <exception>
#include <fstream>
#include <iostream>
#include <sstream>
#include <string>


// low-level function to allocate memory with padding so we can read passed the "length" bytes
// safely.
// if you must provide a pointer to some data, create it with this function:
// length is the max. size in bytes of the string
// caller is responsible to free the memory (free(...))
char * allocate_padded_buffer(size_t length);





// load a file in memory...
// get a corpus; pad out to cache line so we can always use SIMD
// throws exceptions in case of failure
// first element of the pair is a string (null terminated)
// whereas the second element is the length.
// caller is responsible to free (free((void*)result.data())))
// 
// throws an exception if the file cannot be opened, use try/catch
//      try {
//        p = get_corpus(filename);
//      } catch (const std::exception& e) { 
//        free((void*)p.data());//use aligned_free if you plan to use VisualStudio
//        std::cout << "Could not load the file " << filename << std::endl;
//      }
std::string_view  get_corpus(std::string filename);


#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/jsonioutil.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/simdprune_tables.h */
#ifndef SIMDJSON_SIMDPRUNE_TABLES_H
#define SIMDJSON_SIMDPRUNE_TABLES_H


#ifdef __AVX__

static const unsigned char mask128_epi8[] = {
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x8, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xa, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xa, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xa, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xa, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xa,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xb, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xb, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xb, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xb,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xb, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x7, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x7, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x7, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xa, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xa, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xa,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xa, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xa, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xa, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xc, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xc, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xc, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xc, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xc,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xc, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x8, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x8, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xa, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xa,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xa, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xa, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xa, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x7, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xb, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xb,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xb, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xb, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xb, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x7, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x7, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x7, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x7, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xa, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xa,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xa, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xa, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xa, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xa, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7,
    0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7,
    0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x8, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xd, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xd, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xd,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xd, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xd, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xd, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x8, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x9, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x8, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xa,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xa, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xa, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xa, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xa, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xa, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x7, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x7, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xb, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xb, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xb, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xb,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xb, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x7, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x7, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xa,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xa, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xa, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xa, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xa, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xa, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x9, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x8, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xc, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xc, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xc, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xc, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xc,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xc, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x8, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x9, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xa, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xa, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xa, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xa, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xa,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xa, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x7, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7,
    0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7,
    0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7,
    0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7,
    0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x7, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x7, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xb, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xb, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xb, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xb,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xb, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xb, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7,
    0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7,
    0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xa, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xa, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xa, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xa, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xa, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xa,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x8, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x9, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x8, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xe, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xe, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xe, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xe, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xe,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xe, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xa, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xa, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xa, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xa,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xa, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x7, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x7, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x7, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xb, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xb, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xb,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xb, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xb, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xb, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xa, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xa, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xa, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xa, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xa,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xa, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x8, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x9, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x8, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xc, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xc,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xc, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xc, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xc, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x7, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xa,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xa, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xa, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xa, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x7, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x7, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x7, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x7, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xb, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xb,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xb, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xb, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xb, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xb, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x8, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xa, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xa, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xa,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xa, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xa, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xa, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x8, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x9, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x8, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xd,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xd, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xd, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xd, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xd, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xd, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x7, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x7, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xa, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xa, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xa,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xa, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x7, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x7, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xb,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xb, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xb, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xb, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xb, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xb, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x9, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x8, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xa, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xa, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xa, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xa, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xa,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xa, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x8, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x9, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xc, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xc, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xc, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xc, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xc,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xc, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x7, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7,
    0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x7, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x7, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xa, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xa, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xa, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xa,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xa, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xa, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x9, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7,
    0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7,
    0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7,
    0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7,
    0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0xb, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xb, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xb, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0xb, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xb, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xb,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x8, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x8,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x8, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x7,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x7,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x7,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x9, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x9,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x9, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x9, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x9, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x7,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x7,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x7,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x7,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x7,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x7,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x8, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x8,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x8, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6,
    0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6,
    0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6,
    0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6,
    0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x7,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0xa, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0xa, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xa, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0xa, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0xa,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xa, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x7,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x7,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x7,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x8, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x6, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x8,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x5, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x8, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6,
    0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6,
    0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5,
    0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x7,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x7,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5,
    0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5,
    0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5,
    0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5,
    0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5,
    0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5,
    0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x9,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x6, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x9, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5,
    0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x5, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x9, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x9, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x9, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x9, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5,
    0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x7,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5,
    0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x7,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6,
    0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x7,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6,
    0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6,
    0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4,
    0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x4, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x4, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0x8, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0x8, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0x8, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0x8, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5,
    0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5,
    0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4,
    0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4,
    0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5,
    0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5,
    0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x5, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x4, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x4, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x4, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x4, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6,
    0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x6, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x8, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x8, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4,
    0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4,
    0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x4, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x4, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x4, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x4, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x4, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x4, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x8, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x8, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x5, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x4, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x4, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x4, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x4, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x4, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x4, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x8, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x8, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x8, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x8,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x8, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6,
    0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4,
    0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0x4, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0x7,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6,
    0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6,
    0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3,
    0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3,
    0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x3, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x3, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6,
    0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4,
    0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4,
    0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x3, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x3, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x3, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x3, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x6, 0x7, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6,
    0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6,
    0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3,
    0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3,
    0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x3, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x3, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x3, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x3, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x6, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x6, 0x7, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x6, 0x7, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3,
    0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x3, 0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x3, 0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x3, 0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x3, 0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x5, 0x7, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x5, 0x7, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0x7, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0x7, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x3, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x3, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x3, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x3, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x3, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x3, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x5, 0x7, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x5, 0x7, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0x7, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0x7, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x3, 0x4, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x3, 0x4, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x3, 0x4, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x3, 0x4, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x7, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x7, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0x7, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0x7, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0x7,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0x7,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x3, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x3, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x3, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x3, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x7, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x7, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x7, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x7, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x7, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x7, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x7,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x7,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x5, 0x6, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x5, 0x6, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4, 0x5, 0x6,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4, 0x5, 0x6,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x4,
    0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x4,
    0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x4, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x4, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x5, 0x6, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x5, 0x6, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x5, 0x6,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x5, 0x6,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x5, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x6, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x6, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x6, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x6, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x4, 0x6,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x4, 0x6,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x4,
    0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x4,
    0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x4, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x4, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x4, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x4, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x6, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x6, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x6, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x6, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x6,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x6,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2,
    0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2,
    0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x6, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0x5, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0x5, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0x5, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0x5, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4, 0x5, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4, 0x5, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2,
    0x4, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2,
    0x4, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x2, 0x4, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x2, 0x4, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x1, 0x4, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x1, 0x4, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x4, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x4, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x5, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x5, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x5, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x5, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x5, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x5, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1,
    0x2, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1,
    0x2, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x2, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x2, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x1, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x1, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x5, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0x4, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0x4, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0x4, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0x4, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0x4, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0x4, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3, 0x4,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3, 0x4,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0,
    0x1, 0x2, 0x4, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x1, 0x2, 0x4, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x0, 0x2, 0x4, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x2, 0x4, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x0, 0x1, 0x4, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x1, 0x4, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x4, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x4, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x2, 0x3, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x2, 0x3, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x2, 0x3, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x2, 0x3, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0x3, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0x3, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0x3,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x3,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0x0, 0x1, 0x2, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0x1, 0x2, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0x0, 0x2, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0x2, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0x0, 0x1, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0x1, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0x0, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf,
    0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf, 0xf};

static const unsigned char mask128_epi32[] = {
    0x0,  0x1,  0x2,  0x3,  0x4,  0x5,  0x6,  0x7,  0x8,  0x9,  0xa,  0xb,
    0xc,  0xd,  0xe,  0xf,  0x4,  0x5,  0x6,  0x7,  0x8,  0x9,  0xa,  0xb,
    0xc,  0xd,  0xe,  0xf,  0xc,  0xd,  0xe,  0xf,  0x0,  0x1,  0x2,  0x3,
    0x8,  0x9,  0xa,  0xb,  0xc,  0xd,  0xe,  0xf,  0xc,  0xd,  0xe,  0xf,
    0x8,  0x9,  0xa,  0xb,  0xc,  0xd,  0xe,  0xf,  0xc,  0xd,  0xe,  0xf,
    0xc,  0xd,  0xe,  0xf,  0x0,  0x1,  0x2,  0x3,  0x4,  0x5,  0x6,  0x7,
    0xc,  0xd,  0xe,  0xf,  0xc,  0xd,  0xe,  0xf,  0x4,  0x5,  0x6,  0x7,
    0xc,  0xd,  0xe,  0xf,  0xc,  0xd,  0xe,  0xf,  0xc,  0xd,  0xe,  0xf,
    0x0,  0x1,  0x2,  0x3,  0xc,  0xd,  0xe,  0xf,  0xc,  0xd,  0xe,  0xf,
    0xc,  0xd,  0xe,  0xf,  0xc,  0xd,  0xe,  0xf,  0xc,  0xd,  0xe,  0xf,
    0xc,  0xd,  0xe,  0xf,  0xc,  0xd,  0xe,  0xf,  0x0,  0x1,  0x2,  0x3,
    0x4,  0x5,  0x6,  0x7,  0x8,  0x9,  0xa,  0xb,  0x8,  0x9,  0xa,  0xb,
    0x4,  0x5,  0x6,  0x7,  0x8,  0x9,  0xa,  0xb,  0x8,  0x9,  0xa,  0xb,
    0x8,  0x9,  0xa,  0xb,  0x0,  0x1,  0x2,  0x3,  0x8,  0x9,  0xa,  0xb,
    0x8,  0x9,  0xa,  0xb,  0x8,  0x9,  0xa,  0xb,  0x8,  0x9,  0xa,  0xb,
    0x8,  0x9,  0xa,  0xb,  0x8,  0x9,  0xa,  0xb,  0x8,  0x9,  0xa,  0xb,
    0x0,  0x1,  0x2,  0x3,  0x4,  0x5,  0x6,  0x7,  0x4,  0x5,  0x6,  0x7,
    0x4,  0x5,  0x6,  0x7,  0x4,  0x5,  0x6,  0x7,  0x4,  0x5,  0x6,  0x7,
    0x4,  0x5,  0x6,  0x7,  0x4,  0x5,  0x6,  0x7,  0x0,  0x1,  0x2,  0x3,
    0x0,  0x1,  0x2,  0x3,  0x0,  0x1,  0x2,  0x3,  0x0,  0x1,  0x2,  0x3,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff,
};

#endif //__SSE3__

#ifdef __AVX2__

#include <stdint.h>

static const uint32_t mask256_epi32[] = {
    0, 1, 2, 3, 4, 5, 6, 7, 1, 2, 3, 4, 5, 6, 7, 7, 0, 2, 3, 4, 5, 6, 7, 7, 2,
    3, 4, 5, 6, 7, 7, 7, 0, 1, 3, 4, 5, 6, 7, 7, 1, 3, 4, 5, 6, 7, 7, 7, 0, 3,
    4, 5, 6, 7, 7, 7, 3, 4, 5, 6, 7, 7, 7, 7, 0, 1, 2, 4, 5, 6, 7, 7, 1, 2, 4,
    5, 6, 7, 7, 7, 0, 2, 4, 5, 6, 7, 7, 7, 2, 4, 5, 6, 7, 7, 7, 7, 0, 1, 4, 5,
    6, 7, 7, 7, 1, 4, 5, 6, 7, 7, 7, 7, 0, 4, 5, 6, 7, 7, 7, 7, 4, 5, 6, 7, 7,
    7, 7, 7, 0, 1, 2, 3, 5, 6, 7, 7, 1, 2, 3, 5, 6, 7, 7, 7, 0, 2, 3, 5, 6, 7,
    7, 7, 2, 3, 5, 6, 7, 7, 7, 7, 0, 1, 3, 5, 6, 7, 7, 7, 1, 3, 5, 6, 7, 7, 7,
    7, 0, 3, 5, 6, 7, 7, 7, 7, 3, 5, 6, 7, 7, 7, 7, 7, 0, 1, 2, 5, 6, 7, 7, 7,
    1, 2, 5, 6, 7, 7, 7, 7, 0, 2, 5, 6, 7, 7, 7, 7, 2, 5, 6, 7, 7, 7, 7, 7, 0,
    1, 5, 6, 7, 7, 7, 7, 1, 5, 6, 7, 7, 7, 7, 7, 0, 5, 6, 7, 7, 7, 7, 7, 5, 6,
    7, 7, 7, 7, 7, 7, 0, 1, 2, 3, 4, 6, 7, 7, 1, 2, 3, 4, 6, 7, 7, 7, 0, 2, 3,
    4, 6, 7, 7, 7, 2, 3, 4, 6, 7, 7, 7, 7, 0, 1, 3, 4, 6, 7, 7, 7, 1, 3, 4, 6,
    7, 7, 7, 7, 0, 3, 4, 6, 7, 7, 7, 7, 3, 4, 6, 7, 7, 7, 7, 7, 0, 1, 2, 4, 6,
    7, 7, 7, 1, 2, 4, 6, 7, 7, 7, 7, 0, 2, 4, 6, 7, 7, 7, 7, 2, 4, 6, 7, 7, 7,
    7, 7, 0, 1, 4, 6, 7, 7, 7, 7, 1, 4, 6, 7, 7, 7, 7, 7, 0, 4, 6, 7, 7, 7, 7,
    7, 4, 6, 7, 7, 7, 7, 7, 7, 0, 1, 2, 3, 6, 7, 7, 7, 1, 2, 3, 6, 7, 7, 7, 7,
    0, 2, 3, 6, 7, 7, 7, 7, 2, 3, 6, 7, 7, 7, 7, 7, 0, 1, 3, 6, 7, 7, 7, 7, 1,
    3, 6, 7, 7, 7, 7, 7, 0, 3, 6, 7, 7, 7, 7, 7, 3, 6, 7, 7, 7, 7, 7, 7, 0, 1,
    2, 6, 7, 7, 7, 7, 1, 2, 6, 7, 7, 7, 7, 7, 0, 2, 6, 7, 7, 7, 7, 7, 2, 6, 7,
    7, 7, 7, 7, 7, 0, 1, 6, 7, 7, 7, 7, 7, 1, 6, 7, 7, 7, 7, 7, 7, 0, 6, 7, 7,
    7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 0, 1, 2, 3, 4, 5, 7, 7, 1, 2, 3, 4, 5,
    7, 7, 7, 0, 2, 3, 4, 5, 7, 7, 7, 2, 3, 4, 5, 7, 7, 7, 7, 0, 1, 3, 4, 5, 7,
    7, 7, 1, 3, 4, 5, 7, 7, 7, 7, 0, 3, 4, 5, 7, 7, 7, 7, 3, 4, 5, 7, 7, 7, 7,
    7, 0, 1, 2, 4, 5, 7, 7, 7, 1, 2, 4, 5, 7, 7, 7, 7, 0, 2, 4, 5, 7, 7, 7, 7,
    2, 4, 5, 7, 7, 7, 7, 7, 0, 1, 4, 5, 7, 7, 7, 7, 1, 4, 5, 7, 7, 7, 7, 7, 0,
    4, 5, 7, 7, 7, 7, 7, 4, 5, 7, 7, 7, 7, 7, 7, 0, 1, 2, 3, 5, 7, 7, 7, 1, 2,
    3, 5, 7, 7, 7, 7, 0, 2, 3, 5, 7, 7, 7, 7, 2, 3, 5, 7, 7, 7, 7, 7, 0, 1, 3,
    5, 7, 7, 7, 7, 1, 3, 5, 7, 7, 7, 7, 7, 0, 3, 5, 7, 7, 7, 7, 7, 3, 5, 7, 7,
    7, 7, 7, 7, 0, 1, 2, 5, 7, 7, 7, 7, 1, 2, 5, 7, 7, 7, 7, 7, 0, 2, 5, 7, 7,
    7, 7, 7, 2, 5, 7, 7, 7, 7, 7, 7, 0, 1, 5, 7, 7, 7, 7, 7, 1, 5, 7, 7, 7, 7,
    7, 7, 0, 5, 7, 7, 7, 7, 7, 7, 5, 7, 7, 7, 7, 7, 7, 7, 0, 1, 2, 3, 4, 7, 7,
    7, 1, 2, 3, 4, 7, 7, 7, 7, 0, 2, 3, 4, 7, 7, 7, 7, 2, 3, 4, 7, 7, 7, 7, 7,
    0, 1, 3, 4, 7, 7, 7, 7, 1, 3, 4, 7, 7, 7, 7, 7, 0, 3, 4, 7, 7, 7, 7, 7, 3,
    4, 7, 7, 7, 7, 7, 7, 0, 1, 2, 4, 7, 7, 7, 7, 1, 2, 4, 7, 7, 7, 7, 7, 0, 2,
    4, 7, 7, 7, 7, 7, 2, 4, 7, 7, 7, 7, 7, 7, 0, 1, 4, 7, 7, 7, 7, 7, 1, 4, 7,
    7, 7, 7, 7, 7, 0, 4, 7, 7, 7, 7, 7, 7, 4, 7, 7, 7, 7, 7, 7, 7, 0, 1, 2, 3,
    7, 7, 7, 7, 1, 2, 3, 7, 7, 7, 7, 7, 0, 2, 3, 7, 7, 7, 7, 7, 2, 3, 7, 7, 7,
    7, 7, 7, 0, 1, 3, 7, 7, 7, 7, 7, 1, 3, 7, 7, 7, 7, 7, 7, 0, 3, 7, 7, 7, 7,
    7, 7, 3, 7, 7, 7, 7, 7, 7, 7, 0, 1, 2, 7, 7, 7, 7, 7, 1, 2, 7, 7, 7, 7, 7,
    7, 0, 2, 7, 7, 7, 7, 7, 7, 2, 7, 7, 7, 7, 7, 7, 7, 0, 1, 7, 7, 7, 7, 7, 7,
    1, 7, 7, 7, 7, 7, 7, 7, 0, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 0,
    1, 2, 3, 4, 5, 6, 6, 1, 2, 3, 4, 5, 6, 6, 6, 0, 2, 3, 4, 5, 6, 6, 6, 2, 3,
    4, 5, 6, 6, 6, 6, 0, 1, 3, 4, 5, 6, 6, 6, 1, 3, 4, 5, 6, 6, 6, 6, 0, 3, 4,
    5, 6, 6, 6, 6, 3, 4, 5, 6, 6, 6, 6, 6, 0, 1, 2, 4, 5, 6, 6, 6, 1, 2, 4, 5,
    6, 6, 6, 6, 0, 2, 4, 5, 6, 6, 6, 6, 2, 4, 5, 6, 6, 6, 6, 6, 0, 1, 4, 5, 6,
    6, 6, 6, 1, 4, 5, 6, 6, 6, 6, 6, 0, 4, 5, 6, 6, 6, 6, 6, 4, 5, 6, 6, 6, 6,
    6, 6, 0, 1, 2, 3, 5, 6, 6, 6, 1, 2, 3, 5, 6, 6, 6, 6, 0, 2, 3, 5, 6, 6, 6,
    6, 2, 3, 5, 6, 6, 6, 6, 6, 0, 1, 3, 5, 6, 6, 6, 6, 1, 3, 5, 6, 6, 6, 6, 6,
    0, 3, 5, 6, 6, 6, 6, 6, 3, 5, 6, 6, 6, 6, 6, 6, 0, 1, 2, 5, 6, 6, 6, 6, 1,
    2, 5, 6, 6, 6, 6, 6, 0, 2, 5, 6, 6, 6, 6, 6, 2, 5, 6, 6, 6, 6, 6, 6, 0, 1,
    5, 6, 6, 6, 6, 6, 1, 5, 6, 6, 6, 6, 6, 6, 0, 5, 6, 6, 6, 6, 6, 6, 5, 6, 6,
    6, 6, 6, 6, 6, 0, 1, 2, 3, 4, 6, 6, 6, 1, 2, 3, 4, 6, 6, 6, 6, 0, 2, 3, 4,
    6, 6, 6, 6, 2, 3, 4, 6, 6, 6, 6, 6, 0, 1, 3, 4, 6, 6, 6, 6, 1, 3, 4, 6, 6,
    6, 6, 6, 0, 3, 4, 6, 6, 6, 6, 6, 3, 4, 6, 6, 6, 6, 6, 6, 0, 1, 2, 4, 6, 6,
    6, 6, 1, 2, 4, 6, 6, 6, 6, 6, 0, 2, 4, 6, 6, 6, 6, 6, 2, 4, 6, 6, 6, 6, 6,
    6, 0, 1, 4, 6, 6, 6, 6, 6, 1, 4, 6, 6, 6, 6, 6, 6, 0, 4, 6, 6, 6, 6, 6, 6,
    4, 6, 6, 6, 6, 6, 6, 6, 0, 1, 2, 3, 6, 6, 6, 6, 1, 2, 3, 6, 6, 6, 6, 6, 0,
    2, 3, 6, 6, 6, 6, 6, 2, 3, 6, 6, 6, 6, 6, 6, 0, 1, 3, 6, 6, 6, 6, 6, 1, 3,
    6, 6, 6, 6, 6, 6, 0, 3, 6, 6, 6, 6, 6, 6, 3, 6, 6, 6, 6, 6, 6, 6, 0, 1, 2,
    6, 6, 6, 6, 6, 1, 2, 6, 6, 6, 6, 6, 6, 0, 2, 6, 6, 6, 6, 6, 6, 2, 6, 6, 6,
    6, 6, 6, 6, 0, 1, 6, 6, 6, 6, 6, 6, 1, 6, 6, 6, 6, 6, 6, 6, 0, 6, 6, 6, 6,
    6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 0, 1, 2, 3, 4, 5, 5, 5, 1, 2, 3, 4, 5, 5,
    5, 5, 0, 2, 3, 4, 5, 5, 5, 5, 2, 3, 4, 5, 5, 5, 5, 5, 0, 1, 3, 4, 5, 5, 5,
    5, 1, 3, 4, 5, 5, 5, 5, 5, 0, 3, 4, 5, 5, 5, 5, 5, 3, 4, 5, 5, 5, 5, 5, 5,
    0, 1, 2, 4, 5, 5, 5, 5, 1, 2, 4, 5, 5, 5, 5, 5, 0, 2, 4, 5, 5, 5, 5, 5, 2,
    4, 5, 5, 5, 5, 5, 5, 0, 1, 4, 5, 5, 5, 5, 5, 1, 4, 5, 5, 5, 5, 5, 5, 0, 4,
    5, 5, 5, 5, 5, 5, 4, 5, 5, 5, 5, 5, 5, 5, 0, 1, 2, 3, 5, 5, 5, 5, 1, 2, 3,
    5, 5, 5, 5, 5, 0, 2, 3, 5, 5, 5, 5, 5, 2, 3, 5, 5, 5, 5, 5, 5, 0, 1, 3, 5,
    5, 5, 5, 5, 1, 3, 5, 5, 5, 5, 5, 5, 0, 3, 5, 5, 5, 5, 5, 5, 3, 5, 5, 5, 5,
    5, 5, 5, 0, 1, 2, 5, 5, 5, 5, 5, 1, 2, 5, 5, 5, 5, 5, 5, 0, 2, 5, 5, 5, 5,
    5, 5, 2, 5, 5, 5, 5, 5, 5, 5, 0, 1, 5, 5, 5, 5, 5, 5, 1, 5, 5, 5, 5, 5, 5,
    5, 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 0, 1, 2, 3, 4, 4, 4, 4,
    1, 2, 3, 4, 4, 4, 4, 4, 0, 2, 3, 4, 4, 4, 4, 4, 2, 3, 4, 4, 4, 4, 4, 4, 0,
    1, 3, 4, 4, 4, 4, 4, 1, 3, 4, 4, 4, 4, 4, 4, 0, 3, 4, 4, 4, 4, 4, 4, 3, 4,
    4, 4, 4, 4, 4, 4, 0, 1, 2, 4, 4, 4, 4, 4, 1, 2, 4, 4, 4, 4, 4, 4, 0, 2, 4,
    4, 4, 4, 4, 4, 2, 4, 4, 4, 4, 4, 4, 4, 0, 1, 4, 4, 4, 4, 4, 4, 1, 4, 4, 4,
    4, 4, 4, 4, 0, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 0, 1, 2, 3, 3,
    3, 3, 3, 1, 2, 3, 3, 3, 3, 3, 3, 0, 2, 3, 3, 3, 3, 3, 3, 2, 3, 3, 3, 3, 3,
    3, 3, 0, 1, 3, 3, 3, 3, 3, 3, 1, 3, 3, 3, 3, 3, 3, 3, 0, 3, 3, 3, 3, 3, 3,
    3, 3, 3, 3, 3, 3, 3, 3, 3, 0, 1, 2, 2, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2, 2, 2,
    0, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 0, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
#endif //__AVX2__

#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/simdprune_tables.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/simdutf8check.h */

#ifndef SIMDJSON_SIMDUTF8CHECK_H
#define SIMDJSON_SIMDUTF8CHECK_H

#include <stdbool.h>
#include <stddef.h>
#include <stdint.h>
#include <string.h>
/*
 * legal utf-8 byte sequence
 * http://www.unicode.org/versions/Unicode6.0.0/ch03.pdf - page 94
 *
 *  Code Points        1st       2s       3s       4s
 * U+0000..U+007F     00..7F
 * U+0080..U+07FF     C2..DF   80..BF
 * U+0800..U+0FFF     E0       A0..BF   80..BF
 * U+1000..U+CFFF     E1..EC   80..BF   80..BF
 * U+D000..U+D7FF     ED       80..9F   80..BF
 * U+E000..U+FFFF     EE..EF   80..BF   80..BF
 * U+10000..U+3FFFF   F0       90..BF   80..BF   80..BF
 * U+40000..U+FFFFF   F1..F3   80..BF   80..BF   80..BF
 * U+100000..U+10FFFF F4       80..8F   80..BF   80..BF
 *
 */

// all byte values must be no larger than 0xF4


#ifdef __AVX2__

/*****************************/
static inline __m256i push_last_byte_of_a_to_b(__m256i a, __m256i b) {
  return _mm256_alignr_epi8(b, _mm256_permute2x128_si256(a, b, 0x21), 15);
}

static inline __m256i push_last_2bytes_of_a_to_b(__m256i a, __m256i b) {
  return _mm256_alignr_epi8(b, _mm256_permute2x128_si256(a, b, 0x21), 14);
}

// all byte values must be no larger than 0xF4
static inline void avxcheckSmallerThan0xF4(__m256i current_bytes,
                                           __m256i *has_error) {
  // unsigned, saturates to 0 below max
  *has_error = _mm256_or_si256(
      *has_error, _mm256_subs_epu8(current_bytes, _mm256_set1_epi8(0xF4)));
}

static inline __m256i avxcontinuationLengths(__m256i high_nibbles) {
  return _mm256_shuffle_epi8(
      _mm256_setr_epi8(1, 1, 1, 1, 1, 1, 1, 1, // 0xxx (ASCII)
                       0, 0, 0, 0,             // 10xx (continuation)
                       2, 2,                   // 110x
                       3,                      // 1110
                       4, // 1111, next should be 0 (not checked here)
                       1, 1, 1, 1, 1, 1, 1, 1, // 0xxx (ASCII)
                       0, 0, 0, 0,             // 10xx (continuation)
                       2, 2,                   // 110x
                       3,                      // 1110
                       4 // 1111, next should be 0 (not checked here)
                       ),
      high_nibbles);
}

static inline __m256i avxcarryContinuations(__m256i initial_lengths,
                                            __m256i previous_carries) {

  __m256i right1 = _mm256_subs_epu8(
      push_last_byte_of_a_to_b(previous_carries, initial_lengths),
      _mm256_set1_epi8(1));
  __m256i sum = _mm256_add_epi8(initial_lengths, right1);

  __m256i right2 = _mm256_subs_epu8(
      push_last_2bytes_of_a_to_b(previous_carries, sum), _mm256_set1_epi8(2));
  return _mm256_add_epi8(sum, right2);
}

static inline void avxcheckContinuations(__m256i initial_lengths,
                                         __m256i carries, __m256i *has_error) {

  // overlap || underlap
  // carry > length && length > 0 || !(carry > length) && !(length > 0)
  // (carries > length) == (lengths > 0)
  __m256i overunder = _mm256_cmpeq_epi8(
      _mm256_cmpgt_epi8(carries, initial_lengths),
      _mm256_cmpgt_epi8(initial_lengths, _mm256_setzero_si256()));

  *has_error = _mm256_or_si256(*has_error, overunder);
}

// when 0xED is found, next byte must be no larger than 0x9F
// when 0xF4 is found, next byte must be no larger than 0x8F
// next byte must be continuation, ie sign bit is set, so signed < is ok
static inline void avxcheckFirstContinuationMax(__m256i current_bytes,
                                                __m256i off1_current_bytes,
                                                __m256i *has_error) {
  __m256i maskED =
      _mm256_cmpeq_epi8(off1_current_bytes, _mm256_set1_epi8(0xED));
  __m256i maskF4 =
      _mm256_cmpeq_epi8(off1_current_bytes, _mm256_set1_epi8(0xF4));

  __m256i badfollowED = _mm256_and_si256(
      _mm256_cmpgt_epi8(current_bytes, _mm256_set1_epi8(0x9F)), maskED);
  __m256i badfollowF4 = _mm256_and_si256(
      _mm256_cmpgt_epi8(current_bytes, _mm256_set1_epi8(0x8F)), maskF4);

  *has_error =
      _mm256_or_si256(*has_error, _mm256_or_si256(badfollowED, badfollowF4));
}

// map off1_hibits => error condition
// hibits     off1    cur
// C       => < C2 && true
// E       => < E1 && < A0
// F       => < F1 && < 90
// else      false && false
static inline void avxcheckOverlong(__m256i current_bytes,
                                    __m256i off1_current_bytes, __m256i hibits,
                                    __m256i previous_hibits,
                                    __m256i *has_error) {
  __m256i off1_hibits = push_last_byte_of_a_to_b(previous_hibits, hibits);
  __m256i initial_mins = _mm256_shuffle_epi8(
      _mm256_setr_epi8(-128, -128, -128, -128, -128, -128, -128, -128, -128,
                       -128, -128, -128, // 10xx => false
                       0xC2, -128,       // 110x
                       0xE1,             // 1110
                       0xF1, -128, -128, -128, -128, -128, -128, -128, -128,
                       -128, -128, -128, -128, // 10xx => false
                       0xC2, -128,             // 110x
                       0xE1,                   // 1110
                       0xF1),
      off1_hibits);

  __m256i initial_under = _mm256_cmpgt_epi8(initial_mins, off1_current_bytes);

  __m256i second_mins = _mm256_shuffle_epi8(
      _mm256_setr_epi8(-128, -128, -128, -128, -128, -128, -128, -128, -128,
                       -128, -128, -128, // 10xx => false
                       127, 127,         // 110x => true
                       0xA0,             // 1110
                       0x90, -128, -128, -128, -128, -128, -128, -128, -128,
                       -128, -128, -128, -128, // 10xx => false
                       127, 127,               // 110x => true
                       0xA0,                   // 1110
                       0x90),
      off1_hibits);
  __m256i second_under = _mm256_cmpgt_epi8(second_mins, current_bytes);
  *has_error = _mm256_or_si256(*has_error,
                               _mm256_and_si256(initial_under, second_under));
}

struct avx_processed_utf_bytes {
  __m256i rawbytes;
  __m256i high_nibbles;
  __m256i carried_continuations;
};

static inline void avx_count_nibbles(__m256i bytes,
                                     struct avx_processed_utf_bytes *answer) {
  answer->rawbytes = bytes;
  answer->high_nibbles =
      _mm256_and_si256(_mm256_srli_epi16(bytes, 4), _mm256_set1_epi8(0x0F));
}

// check whether the current bytes are valid UTF-8
// at the end of the function, previous gets updated
static struct avx_processed_utf_bytes
avxcheckUTF8Bytes(__m256i current_bytes,
                  struct avx_processed_utf_bytes *previous,
                  __m256i *has_error) {
  struct avx_processed_utf_bytes pb;
  avx_count_nibbles(current_bytes, &pb);

  avxcheckSmallerThan0xF4(current_bytes, has_error);

  __m256i initial_lengths = avxcontinuationLengths(pb.high_nibbles);

  pb.carried_continuations =
      avxcarryContinuations(initial_lengths, previous->carried_continuations);

  avxcheckContinuations(initial_lengths, pb.carried_continuations, has_error);

  __m256i off1_current_bytes =
      push_last_byte_of_a_to_b(previous->rawbytes, pb.rawbytes);
  avxcheckFirstContinuationMax(current_bytes, off1_current_bytes, has_error);

  avxcheckOverlong(current_bytes, off1_current_bytes, pb.high_nibbles,
                   previous->high_nibbles, has_error);
  return pb;
}

#else // __AVX2__
#warning "We require AVX2 support!"
#endif // __AVX2__
#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/simdutf8check.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/jsonminifier.h */
#ifndef SIMDJSON_JSONMINIFIER_H
#define SIMDJSON_JSONMINIFIER_H

#include <cstddef>
#include <cstdint>

// Take input from buf and remove useless whitespace, write it to out; buf and
// out can be the same pointer. Result is null terminated,
// return the string length (minus the null termination).
size_t jsonminify(const uint8_t *buf, size_t len, uint8_t *out);


static inline size_t jsonminify(const char *buf, size_t len, char *out) {
    return jsonminify((const uint8_t *)buf, len, (uint8_t *)out);
}


static inline size_t jsonminify(const std::string_view & p, char *out) {
    return jsonminify(p.data(), p.size(), out);
}

#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/jsonminifier.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/parsedjson.h */
#ifndef SIMDJSON_PARSEDJSON_H
#define SIMDJSON_PARSEDJSON_H

#include <math.h>
#include <inttypes.h>
#include <string.h>
#include <iomanip>
#include <iostream>


#define JSONVALUEMASK 0xFFFFFFFFFFFFFF

#define DEFAULTMAXDEPTH 1024// a JSON document with a depth exceeding 1024 is probably de facto invalid


/************
 * The JSON is parsed to a tape, see the accompanying tape.md file
 * for documentation.
 ***********/
struct ParsedJson {
public:

  // create a ParsedJson container with zero capacity, call allocateCapacity to
  // allocate memory
  ParsedJson()
      : bytecapacity(0), depthcapacity(0), tapecapacity(0), stringcapacity(0),
        current_loc(0), n_structural_indexes(0),
        structural_indexes(NULL), tape(NULL), containing_scope_offset(NULL),
        ret_address(NULL), string_buf(NULL), current_string_buf_loc(NULL), isvalid(false) {}

  // if needed, allocate memory so that the object is able to process JSON
  // documents having up to len butes and maxdepth "depth"
  WARN_UNUSED
  inline bool allocateCapacity(size_t len, size_t maxdepth = DEFAULTMAXDEPTH) {
    if ((maxdepth == 0) || (len == 0)) {
      std::cerr << "capacities must be non-zero " << std::endl;
      return false;
    }
    if (len > 0) {
      if ((len <= bytecapacity) && (depthcapacity < maxdepth))
        return true;
      deallocate();
    }
    isvalid = false;
    bytecapacity = 0; // will only set it to len after allocations are a success
    n_structural_indexes = 0;
    uint32_t max_structures = ROUNDUP_N(len, 64) + 2 + 7;
    structural_indexes = new uint32_t[max_structures];
    size_t localtapecapacity = ROUNDUP_N(len, 64);
    size_t localstringcapacity = ROUNDUP_N(len, 64);
    string_buf = new uint8_t[localstringcapacity];
    tape = new uint64_t[localtapecapacity];
    containing_scope_offset = new uint32_t[maxdepth];
#ifdef SIMDJSON_USE_COMPUTED_GOTO
    ret_address = new void *[maxdepth];
#else
    ret_address = new char[maxdepth];
#endif
    if ((string_buf == NULL) || (tape == NULL) ||
        (containing_scope_offset == NULL) || (ret_address == NULL) || (structural_indexes == NULL)) {
      std::cerr << "Could not allocate memory" << std::endl;
      if(ret_address != NULL) delete[] ret_address;
      if(containing_scope_offset != NULL) delete[] containing_scope_offset;
      if(tape != NULL) delete[] tape;
      if(string_buf != NULL) delete[] string_buf;
      if(structural_indexes != NULL) delete[] structural_indexes;
      return false;
    }

    bytecapacity = len;
    depthcapacity = maxdepth;
    tapecapacity = localtapecapacity;
    stringcapacity = localstringcapacity;
    return true;
  }

  bool isValid() const {
    return isvalid;
  }

  // deallocate memory and set capacity to zero, called automatically by the
  // destructor
  void deallocate() {
    bytecapacity = 0;
    depthcapacity = 0;
    tapecapacity = 0;
    stringcapacity = 0;
    if(ret_address != NULL) delete[] ret_address;
    if(containing_scope_offset != NULL) delete[] containing_scope_offset;
    if(tape != NULL) delete[] tape;
    if(string_buf != NULL) delete[] string_buf;
    if(structural_indexes != NULL) delete[] structural_indexes;
    isvalid = false;
  }

  ~ParsedJson() { deallocate(); }

  // this should be called when parsing (right before writing the tapes)
  void init() {
    current_string_buf_loc = string_buf;
    current_loc = 0;
    isvalid = false;
  }

  // print the json to stdout (should be valid)
  // return false if the tape is likely wrong (e.g., you did not parse a valid
  // JSON).
  WARN_UNUSED
  bool printjson(std::ostream &os) {
    if(!isvalid) return false;
    size_t tapeidx = 0;
    uint64_t tape_val = tape[tapeidx];
    uint8_t type = (tape_val >> 56);
    size_t howmany = 0;
    if (type == 'r') {
      howmany = tape_val & JSONVALUEMASK;
    } else {
      fprintf(stderr, "Error: no starting root node?");
      return false;
    }
    if (howmany > tapecapacity) {
      fprintf(stderr, 
          "We may be exceeding the tape capacity. Is this a valid document?\n");
      return false;
    }
    tapeidx++;
    bool *inobject = new bool[depthcapacity];
    size_t *inobjectidx = new size_t[depthcapacity];
    int depth = 1; // only root at level 0
    inobjectidx[depth] = 0;
    inobject[depth] = false;
    for (; tapeidx < howmany; tapeidx++) {
      tape_val = tape[tapeidx];
      uint64_t payload = tape_val & JSONVALUEMASK;
      type = (tape_val >> 56);
      if (!inobject[depth]) {
        if ((inobjectidx[depth] > 0) && (type != ']'))
          os << ",";
        inobjectidx[depth]++;
      } else { // if (inobject) {
        if ((inobjectidx[depth] > 0) && ((inobjectidx[depth] & 1) == 0) &&
            (type != '}'))
          os << ",";
        if (((inobjectidx[depth] & 1) == 1))
          os << ":";
        inobjectidx[depth]++;
      }
      switch (type) {
      case '"': // we have a string
        os << '"';
        print_with_escapes((const unsigned char *)(string_buf + payload));
        os << '"';
        break;
      case 'l': // we have a long int
        if (tapeidx + 1 >= howmany)
          return false;
        os <<  (int64_t)tape[++tapeidx];
        break;
      case 'd': // we have a double
        if (tapeidx + 1 >= howmany)
          return false;
        double answer;
        memcpy(&answer, &tape[++tapeidx], sizeof(answer));
        os << answer;
        break;
      case 'n': // we have a null
        os << "null";
        break;
      case 't': // we have a true
        os << "true";
        break;
      case 'f': // we have a false
        os << "false";
        break;
      case '{': // we have an object
        os << '{';
        depth++;
        inobject[depth] = true;
        inobjectidx[depth] = 0;
        break;
      case '}': // we end an object
        depth--;
        os << '}';
        break;
      case '[': // we start an array
        os << '[';
        depth++;
        inobject[depth] = false;
        inobjectidx[depth] = 0;
        break;
      case ']': // we end an array
        depth--;
        os << ']';
        break;
      case 'r': // we start and end with the root node
        fprintf(stderr, "should we be hitting the root node?\n");
        delete[] inobject;
        delete[] inobjectidx;
        return false;
      default:
        fprintf(stderr, "bug %c\n", type);
        delete[] inobject;
        delete[] inobjectidx;
        return false;
      }
    }
    delete[] inobject;
    delete[] inobjectidx;
    return true;
  }

  WARN_UNUSED
  bool dump_raw_tape(std::ostream &os) {
    if(!isvalid) return false;
    size_t tapeidx = 0;
    uint64_t tape_val = tape[tapeidx];
    uint8_t type = (tape_val >> 56);
    os << tapeidx << " : " << type;
    tapeidx++;
    size_t howmany = 0;
    if (type == 'r') {
      howmany = tape_val & JSONVALUEMASK;
    } else {
      fprintf(stderr, "Error: no starting root node?");
      return false;
    }
    os << "\t// pointing to " << howmany <<" (right after last node)\n";
    uint64_t payload;
    for (; tapeidx < howmany; tapeidx++) {
      os << tapeidx << " : ";
      tape_val = tape[tapeidx];
      payload = tape_val & JSONVALUEMASK;
      type = (tape_val >> 56);
      switch (type) {
      case '"': // we have a string
        os << "string \"";
        print_with_escapes((const unsigned char *)(string_buf + payload));
        os << '"';
        os << '\n';
        break;
      case 'l': // we have a long int
        if (tapeidx + 1 >= howmany)
          return false;
        os << "integer " << (int64_t)tape[++tapeidx] << "\n";
        break;
      case 'd': // we have a double
        os << "float ";
        if (tapeidx + 1 >= howmany)
          return false;
        double answer;
        memcpy(&answer, &tape[++tapeidx], sizeof(answer));
        os << answer << '\n';
        break;
      case 'n': // we have a null
        os << "null\n";
        break;
      case 't': // we have a true
        os << "true\n";
        break;
      case 'f': // we have a false
        os << "false\n";
        break;
      case '{': // we have an object
        os << "{\t// pointing to next tape location " << payload << " (first node after the scope) \n";
        break;
      case '}': // we end an object
        os << "}\t// pointing to previous tape location " << payload << " (start of the scope) \n";
        break;
      case '[': // we start an array
        os << "[\t// pointing to next tape location " << payload << " (first node after the scope) \n";
        break;
      case ']': // we end an array
        os << "]\t// pointing to previous tape location " << payload << " (start of the scope) \n";
        break;
      case 'r': // we start and end with the root node
        printf("end of root\n");
        return false;
      default:
        return false;
      }
    }
    tape_val = tape[tapeidx];
    payload = tape_val & JSONVALUEMASK;
    type = (tape_val >> 56);
    os << tapeidx << " : "<< type <<"\t// pointing to " << payload <<" (start root)\n";
    return true;
  }


  // all nodes are stored on the tape using a 64-bit word.
  //
  // strings, double and ints are stored as
  //  a 64-bit word with a pointer to the actual value
  //
  //
  //
  // for objects or arrays, store [ or {  at the beginning and } and ] at the
  // end. For the openings ([ or {), we annotate them with a reference to the
  // location on the tape of the end, and for then closings (} and ]), we
  // annotate them with a reference to the location of the opening
  //
  //

  // this should be considered a private function
  really_inline void write_tape(uint64_t val, uint8_t c) {
    tape[current_loc++] = val | (((uint64_t)c) << 56);
  }

  really_inline void write_tape_s64(int64_t i) {
    write_tape(0, 'l');
    tape[current_loc++] = *((uint64_t *)&i);
  }

  really_inline void write_tape_double(double d) {
    write_tape(0, 'd');
    static_assert(sizeof(d) == sizeof(tape[current_loc]), "mismatch size");
    memcpy(& tape[current_loc++], &d, sizeof(double));
    //tape[current_loc++] = *((uint64_t *)&d);
  }

  really_inline uint32_t get_current_loc() { return current_loc; }

  really_inline void annotate_previousloc(uint32_t saved_loc, uint64_t val) {
    tape[saved_loc] |= val;
  }



  struct iterator {

    explicit iterator(ParsedJson &pj_)
        : pj(pj_), depth(0), location(0), tape_length(0), depthindex(NULL) {
        if(pj.isValid()) {
            depthindex = new scopeindex_t[pj.depthcapacity];
            if(depthindex == NULL) return;
            depthindex[0].start_of_scope = location;
            current_val = pj.tape[location++];
            current_type = (current_val >> 56);
            depthindex[0].scope_type = current_type;
            if (current_type == 'r') {
              tape_length = current_val & JSONVALUEMASK;
              if(location < tape_length) {
                current_val = pj.tape[location];
                current_type = (current_val >> 56);
                depth++;
                depthindex[depth].start_of_scope = location;
                depthindex[depth].scope_type = current_type;
              }
            }
        }
    }
    ~iterator() {
      delete[] depthindex;
    }

    iterator(const iterator &o):
      pj(o.pj), depth(o.depth), location(o.location),
      tape_length(o.tape_length), current_type(o.current_type),
      current_val(o.current_val), depthindex(NULL) {
        depthindex = new scopeindex_t[pj.depthcapacity];
        if(depthindex != NULL) {
          memcpy(o.depthindex, depthindex, pj.depthcapacity * sizeof(depthindex[0]));
        } else {
          tape_length = 0;
        }
    }

    iterator(iterator &&o):
      pj(o.pj), depth(std::move(o.depth)), location(std::move(o.location)),
      tape_length(std::move(o.tape_length)), current_type(std::move(o.current_type)),
      current_val(std::move(o.current_val)), depthindex(std::move(o.depthindex)) {
        o.depthindex = NULL;// we take ownership
    }

    WARN_UNUSED
    bool isOk() const {
      return location < tape_length;
    }

    // useful for debuging purposes
    size_t get_tape_location() const {
      return location;
    }

    // useful for debuging purposes
    size_t get_tape_length() const {
      return tape_length;
    }

    // returns the current depth (start at 1 with 0 reserved for the fictitious root node)
    size_t get_depth() const {
      return depth;
    }

    // A scope is a series of nodes at the same depth, typically it is either an object ({) or an array ([).
    // The root node has type 'r'.
    uint8_t get_scope_type() const {
      return depthindex[depth].scope_type;
    }

    // move forward in document order
    bool move_forward() {
      if(location + 1 >= tape_length) {
        return false; // we are at the end!
      }
      // we are entering a new scope
      if ((current_type == '[') || (current_type == '{')){
        depth++;
        depthindex[depth].start_of_scope = location;
        depthindex[depth].scope_type = current_type;
      }
      location = location + 1;
      current_val = pj.tape[location];
      current_type = (current_val >> 56);
      // if we encounter a scope closure, we need to move up
      while ((current_type == ']') || (current_type == '}')) {
        if(location + 1 >= tape_length) {
          return false; // we are at the end!
        }
        depth--;
        if(depth == 0) {
          return false; // should not be necessary
        }
        location = location + 1;
        current_val = pj.tape[location];
        current_type = (current_val >> 56);
      }
      return true;
    }

    // retrieve the character code of what we're looking at:
    // [{"sltfn are the possibilities
    really_inline uint8_t get_type()  const {
      return current_type;
    }

    // get the int64_t value at this node; valid only if we're at "l"
    really_inline int64_t get_integer()  const {
       if(location + 1 >= tape_length) return 0;// default value in case of error
       return (int64_t) pj.tape[location + 1];
    }

    // get the double value at this node; valid only if
    // we're at "d"
    really_inline double get_double()  const {
       if(location + 1 >= tape_length) return NAN;// default value in case of error
       double answer;
       memcpy(&answer, & pj.tape[location + 1], sizeof(answer));
       return answer;
    }

    bool is_object_or_array() const {
      return is_object_or_array(get_type());
    }

    bool is_object() const {
      return get_type() == '{';
    }

    bool is_array() const {
      return get_type() == '[';
    }

    bool is_string() const {
      return get_type() == '"';
    }

    bool is_integer() const {
      return get_type() == 'l';
    }

    bool is_double() const {
      return get_type() == 'd';
    }

    static bool is_object_or_array(uint8_t type) {
      return (type == '[' || (type == '{'));
    }

    // when at {, go one level deep, looking for a given key
    // if successful, we are left pointing at the value,
    // if not, we are still pointing at the object ({)
    // (in case of repeated keys, this only finds the first one)
    bool move_to_key(const char * key) {
      if(down()) {
        do {
          assert(is_string());
          bool rightkey = (strcmp(get_string(),key)==0);
          next();
          if(rightkey) return true;
        } while(next());
        assert(up());// not found
      }
      return false;
    }

    // get the string value at this node (NULL ended); valid only if we're at "
    // note that tabs, and line endings are escaped in the returned value (see print_with_escapes)
    // return value is valid UTF-8
    really_inline const char * get_string() const {
      return  (const char *)(pj.string_buf + (current_val & JSONVALUEMASK)) ;
    }

    // throughout return true if we can do the navigation, false
    // otherwise

    // Withing a given scope (series of nodes at the same depth within either an
    // array or an object), we move forward.
    // Thus, given [true, null, {"a":1}, [1,2]], we would visit true, null, { and [.
    // At the object ({) or at the array ([), you can issue a "down" to visit their content.
    // valid if we're not at the end of a scope (returns true).
    really_inline bool next() {
      if ((current_type == '[') || (current_type == '{')){
        // we need to jump
        size_t npos = ( current_val & JSONVALUEMASK);
        if(npos >= tape_length) {
          return false; // shoud never happen unless at the root
        }
        uint64_t nextval = pj.tape[npos];
        uint8_t nexttype = (nextval >> 56);
        if((nexttype == ']') || (nexttype == '}')) {
          return false; // we reached the end of the scope
        }
        location = npos;
        current_val = nextval;
        current_type = nexttype;
        return true;
      } else {
        size_t increment = (current_type == 'd' || current_type == 'l') ? 2 : 1;
        if(location + increment >= tape_length) return false;
        uint64_t nextval = pj.tape[location + increment];
        uint8_t nexttype = (nextval >> 56);
        if((nexttype == ']') || (nexttype == '}')) {
          return false; // we reached the end of the scope
        }
        location = location + increment;
        current_val = nextval;
        current_type = nexttype;
        return true;
      }
    }



    // Withing a given scope (series of nodes at the same depth within either an
    // array or an object), we move backward.
    // Thus, given [true, null, {"a":1}, [1,2]], we would visit ], }, null, true when starting at the end
    // of the scope.
    // At the object ({) or at the array ([), you can issue a "down" to visit their content.
    really_inline bool prev() {
      if(location - 1 < depthindex[depth].start_of_scope) return false;
      location -= 1;
      current_val = pj.tape[location];
      current_type = (current_val >> 56);
      if ((current_type == ']') || (current_type == '}')){
        // we need to jump
        size_t new_location = ( current_val & JSONVALUEMASK);
        if(new_location < depthindex[depth].start_of_scope) {
          return false; // shoud never happen
        }
        location = new_location;
        current_val = pj.tape[location];
        current_type = (current_val >> 56);
      }
      return true;
    }

    // Moves back to either the containing array or object (type { or [) from
    // within a contained scope.
    // Valid unless we are at the first level of the document
    //
    really_inline bool up() {
      if(depth == 1) {
        return false; // don't allow moving back to root
      }
      to_start_scope();
      // next we just move to the previous value
      depth--;
      location -= 1;
      current_val = pj.tape[location];
      current_type = (current_val >> 56);
      return true;
    }


    // Valid if we're at a [ or { and it starts a non-empty scope; moves us to start of
    // that deeper scope if it not empty.
    // Thus, given [true, null, {"a":1}, [1,2]], if we are at the { node, we would move to the
    // "a" node.
    really_inline bool down() {
      if(location + 1 >= tape_length) return false;
      if ((current_type == '[') || (current_type == '{')) {
        size_t npos = (current_val & JSONVALUEMASK);
        if(npos == location + 2) {
          return false; // we have an empty scope
        }
        depth++;
        location = location + 1;
        depthindex[depth].start_of_scope = location;
        depthindex[depth].scope_type = current_type;
        current_val = pj.tape[location];
        current_type = (current_val >> 56);
        return true;
      }
      return false;
    }

    // move us to the start of our current scope,
    // a scope is a series of nodes at the same level
    void to_start_scope()  {
      location = depthindex[depth].start_of_scope;
      current_val = pj.tape[location];
      current_type = (current_val >> 56);
    }

    // void to_end_scope();              // move us to
    // the start of our current scope; always succeeds

    // print the thing we're currently pointing at
    bool print(std::ostream &os, bool escape_strings = true) const {
      if(!isOk()) return false;
      switch (current_type) {
      case '"': // we have a string
        os << '"';
        if(escape_strings) {
          print_with_escapes(get_string(), os);
        } else {
          os << get_string();
        }
        os << '"';
        break;
      case 'l': // we have a long int
        os << get_integer();
        break;
      case 'd':
        os << get_double();
        break;
      case 'n': // we have a null
        os << "null";
        break;
      case 't': // we have a true
        os << "true";
        break;
      case 'f': // we have a false
        os << "false";
        break;
      case '{': // we have an object
      case '}': // we end an object
      case '[': // we start an array
      case ']': // we end an array
        os << (char) current_type;
        break;
      default:
        return false;
      }
      return true;
    }

    typedef struct {size_t start_of_scope; uint8_t scope_type;} scopeindex_t;

private:

    iterator& operator=(const iterator& other) ;

    ParsedJson &pj;
    size_t depth;
    size_t location;     // our current location on a tape
    size_t tape_length;
    uint8_t current_type;
    uint64_t current_val;
    scopeindex_t *depthindex;

  };


  size_t bytecapacity;  // indicates how many bits are meant to be supported 

  size_t depthcapacity; // how deep we can go
  size_t tapecapacity;
  size_t stringcapacity;
  uint32_t current_loc;
  uint32_t n_structural_indexes;

  uint32_t *structural_indexes;

  uint64_t *tape;
  uint32_t *containing_scope_offset;
#ifdef SIMDJSON_USE_COMPUTED_GOTO
  void **ret_address;
#else 
  char *ret_address;
#endif

  uint8_t *string_buf; // should be at least bytecapacity
  uint8_t *current_string_buf_loc;
  bool isvalid;

  ParsedJson(ParsedJson && p)
      : bytecapacity(std::move(p.bytecapacity)), 
        depthcapacity(std::move(p.depthcapacity)), 
        tapecapacity(std::move(p.tapecapacity)), 
        stringcapacity(std::move(p.stringcapacity)),
        current_loc(std::move(p.current_loc)), 
        n_structural_indexes(std::move(p.n_structural_indexes)),
        structural_indexes(std::move(p.structural_indexes)), 
        tape(std::move(p.tape)), 
        containing_scope_offset(std::move(p.containing_scope_offset)),
        ret_address(std::move(p.ret_address)), 
        string_buf(std::move(p.string_buf)), 
        current_string_buf_loc(std::move(p.current_string_buf_loc)), 
        isvalid(std::move(p.isvalid)) {
          p.structural_indexes=NULL;
          p.tape=NULL;
          p.containing_scope_offset=NULL;
          p.ret_address=NULL;
          p.string_buf=NULL;
          p.current_string_buf_loc=NULL;
        }

private :

 // we don't want the default constructor to be called
 ParsedJson(const ParsedJson & p); // we don't want the default constructor to be called
 // we don't want the assignment to be called
 ParsedJson & operator=(const ParsedJson&o);


};


// dump bits low to high
inline void dumpbits_always(uint64_t v, const std::string &msg) {
  for (uint32_t i = 0; i < 64; i++) {
    std::cout << (((v >> (uint64_t)i) & 0x1ULL) ? "1" : "_");
  }
  std::cout << " " << msg.c_str() << "\n";
}

inline void dumpbits32_always(uint32_t v, const std::string &msg) {
  for (uint32_t i = 0; i < 32; i++) {
    std::cout << (((v >> (uint32_t)i) & 0x1ULL) ? "1" : "_");
  }
  std::cout << " " << msg.c_str() << "\n";
}


#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/parsedjson.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/stage1_find_marks.h */
#ifndef SIMDJSON_STAGE1_FIND_MARKS_H
#define SIMDJSON_STAGE1_FIND_MARKS_H


WARN_UNUSED
bool find_structural_bits(const uint8_t *buf, size_t len, ParsedJson &pj);

WARN_UNUSED
static inline bool find_structural_bits(const char *buf, size_t len, ParsedJson &pj) {
    return find_structural_bits((const uint8_t *)buf, len, pj);
}

#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/stage1_find_marks.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/stringparsing.h */
#ifndef SIMDJSON_STRINGPARSING_H
#define SIMDJSON_STRINGPARSING_H



// begin copypasta
// These chars yield themselves: " \ /
// b -> backspace, f -> formfeed, n -> newline, r -> cr, t -> horizontal tab
// u not handled in this table as it's complex
static const uint8_t escape_map[256] = {
    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0, // 0x0.
    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0,
    0, 0, 0x22, 0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0x2f,
    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0,

    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0, // 0x4.
    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0x5c, 0, 0,    0, // 0x5.
    0, 0, 0x08, 0, 0,    0, 0x0c, 0, 0, 0, 0, 0, 0,    0, 0x0a, 0, // 0x6.
    0, 0, 0x0d, 0, 0x09, 0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0, // 0x7.

    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0,
    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0,
    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0,
    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0,

    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0,
    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0,
    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0,
    0, 0, 0,    0, 0,    0, 0,    0, 0, 0, 0, 0, 0,    0, 0,    0,
};


// handle a unicode codepoint
// write appropriate values into dest
// src will advance 6 bytes or 12 bytes
// dest will advance a variable amount (return via pointer)
// return true if the unicode codepoint was valid
// We work in little-endian then swap at write time
WARN_UNUSED
really_inline bool handle_unicode_codepoint(const uint8_t **src_ptr, uint8_t **dst_ptr) {
  uint32_t code_point = hex_to_u32_nocheck(*src_ptr + 2);
  *src_ptr += 6;
  // check for low surrogate for characters outside the Basic
  // Multilingual Plane.
  if (code_point >= 0xd800 && code_point < 0xdc00) {
    if (((*src_ptr)[0] != '\\') || (*src_ptr)[1] != 'u') {
      return false;
    }
    uint32_t code_point_2 = hex_to_u32_nocheck(*src_ptr + 2);
    code_point =
        (((code_point - 0xd800) << 10) | (code_point_2 - 0xdc00)) + 0x10000;
    *src_ptr += 6;
  }
  size_t offset = codepoint_to_utf8(code_point, *dst_ptr);
  *dst_ptr += offset;
  return offset > 0;
}

WARN_UNUSED
really_inline  bool parse_string(const uint8_t *buf, UNUSED size_t len,
                                ParsedJson &pj, UNUSED const uint32_t depth, uint32_t offset) {
#ifdef SIMDJSON_SKIPSTRINGPARSING // for performance analysis, it is sometimes useful to skip parsing
  pj.write_tape(0, '"');// don't bother with the string parsing at all
  return true; // always succeeds
#else
  const uint8_t *src = &buf[offset + 1]; // we know that buf at offset is a "
  uint8_t *dst = pj.current_string_buf_loc;
#ifdef JSON_TEST_STRINGS // for unit testing
  uint8_t *const start_of_string = dst;
#endif
  while (1) {
    __m256i v = _mm256_loadu_si256((const __m256i *)(src));
    uint32_t bs_bits =
        (uint32_t)_mm256_movemask_epi8(_mm256_cmpeq_epi8(v, _mm256_set1_epi8('\\')));
    uint32_t quote_bits =
        (uint32_t)_mm256_movemask_epi8(_mm256_cmpeq_epi8(v, _mm256_set1_epi8('"')));
#define CHECKUNESCAPED
    // All Unicode characters may be placed within the
    // quotation marks, except for the characters that MUST be escaped:
    // quotation mark, reverse solidus, and the control characters (U+0000
    //through U+001F).
    // https://tools.ietf.org/html/rfc8259
#ifdef CHECKUNESCAPED
    __m256i unitsep = _mm256_set1_epi8(0x1F);
    __m256i unescaped_vec = _mm256_cmpeq_epi8(_mm256_max_epu8(unitsep,v),unitsep);// could do it with saturated subtraction
#endif // CHECKUNESCAPED

    uint32_t quote_dist = trailingzeroes(quote_bits);
    uint32_t bs_dist = trailingzeroes(bs_bits);
    // store to dest unconditionally - we can overwrite the bits we don't like
    // later
    _mm256_storeu_si256((__m256i *)(dst), v);
    if (quote_dist < bs_dist) {
      // we encountered quotes first. Move dst to point to quotes and exit
      dst[quote_dist] = 0; // null terminate and get out

      pj.write_tape(pj.current_string_buf_loc - pj.string_buf, '"');

      pj.current_string_buf_loc = dst + quote_dist + 1; // the +1 is due to the 0 value
#ifdef CHECKUNESCAPED
      // check that there is no unescaped char before the quote
      uint32_t unescaped_bits = (uint32_t)_mm256_movemask_epi8(unescaped_vec);
      bool is_ok = ((quote_bits - 1) & (~ quote_bits) & unescaped_bits) == 0;
#ifdef JSON_TEST_STRINGS // for unit testing
       if(is_ok) foundString(buf + offset,start_of_string,pj.current_string_buf_loc - 1);
       else  foundBadString(buf + offset);
#endif // JSON_TEST_STRINGS
      return is_ok;
#else  //CHECKUNESCAPED
#ifdef JSON_TEST_STRINGS // for unit testing
       foundString(buf + offset,start_of_string,pj.current_string_buf_loc - 1);
#endif // JSON_TEST_STRINGS
      return true;
#endif //CHECKUNESCAPED
    } else if (quote_dist > bs_dist) {
      uint8_t escape_char = src[bs_dist + 1];
#ifdef CHECKUNESCAPED
      // we are going to need the unescaped_bits to check for unescaped chars
      uint32_t unescaped_bits = (uint32_t)_mm256_movemask_epi8(unescaped_vec);
      if(((bs_bits - 1) & (~ bs_bits) & unescaped_bits) != 0) {
#ifdef JSON_TEST_STRINGS // for unit testing
        foundBadString(buf + offset);
#endif // JSON_TEST_STRINGS
        return false;
      }
#endif //CHECKUNESCAPED
      // we encountered backslash first. Handle backslash
      if (escape_char == 'u') {
        // move src/dst up to the start; they will be further adjusted
        // within the unicode codepoint handling code.
        src += bs_dist;
        dst += bs_dist;
        if (!handle_unicode_codepoint(&src, &dst)) {
#ifdef JSON_TEST_STRINGS // for unit testing
          foundBadString(buf + offset);
#endif // JSON_TEST_STRINGS
          return false;
        }
      } else {
        // simple 1:1 conversion. Will eat bs_dist+2 characters in input and
        // write bs_dist+1 characters to output
        // note this may reach beyond the part of the buffer we've actually
        // seen. I think this is ok
        uint8_t escape_result = escape_map[escape_char];
        if (!escape_result) {
#ifdef JSON_TEST_STRINGS // for unit testing
          foundBadString(buf + offset);
#endif // JSON_TEST_STRINGS
          return false; // bogus escape value is an error
        }
        dst[bs_dist] = escape_result;
        src += bs_dist + 2;
        dst += bs_dist + 1;
      }
    } else {
      // they are the same. Since they can't co-occur, it means we encountered
      // neither.
      src += 32;
      dst += 32;
#ifdef CHECKUNESCAPED
      // check for unescaped chars
      if(_mm256_testz_si256(unescaped_vec,unescaped_vec) != 1) {
#ifdef JSON_TEST_STRINGS // for unit testing
          foundBadString(buf + offset);
#endif // JSON_TEST_STRINGS
        return false;
      }
#endif // CHECKUNESCAPED
    }
  }
  // can't be reached
  return true;
#endif // SIMDJSON_SKIPSTRINGPARSING
}


#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/stringparsing.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/numberparsing.h */
#ifndef SIMDJSON_NUMBERPARSING_H
#define SIMDJSON_NUMBERPARSING_H


static const double power_of_ten[] = {
    1e-308, 1e-307, 1e-306, 1e-305, 1e-304, 1e-303, 1e-302, 1e-301, 1e-300,
    1e-299, 1e-298, 1e-297, 1e-296, 1e-295, 1e-294, 1e-293, 1e-292, 1e-291,
    1e-290, 1e-289, 1e-288, 1e-287, 1e-286, 1e-285, 1e-284, 1e-283, 1e-282,
    1e-281, 1e-280, 1e-279, 1e-278, 1e-277, 1e-276, 1e-275, 1e-274, 1e-273,
    1e-272, 1e-271, 1e-270, 1e-269, 1e-268, 1e-267, 1e-266, 1e-265, 1e-264,
    1e-263, 1e-262, 1e-261, 1e-260, 1e-259, 1e-258, 1e-257, 1e-256, 1e-255,
    1e-254, 1e-253, 1e-252, 1e-251, 1e-250, 1e-249, 1e-248, 1e-247, 1e-246,
    1e-245, 1e-244, 1e-243, 1e-242, 1e-241, 1e-240, 1e-239, 1e-238, 1e-237,
    1e-236, 1e-235, 1e-234, 1e-233, 1e-232, 1e-231, 1e-230, 1e-229, 1e-228,
    1e-227, 1e-226, 1e-225, 1e-224, 1e-223, 1e-222, 1e-221, 1e-220, 1e-219,
    1e-218, 1e-217, 1e-216, 1e-215, 1e-214, 1e-213, 1e-212, 1e-211, 1e-210,
    1e-209, 1e-208, 1e-207, 1e-206, 1e-205, 1e-204, 1e-203, 1e-202, 1e-201,
    1e-200, 1e-199, 1e-198, 1e-197, 1e-196, 1e-195, 1e-194, 1e-193, 1e-192,
    1e-191, 1e-190, 1e-189, 1e-188, 1e-187, 1e-186, 1e-185, 1e-184, 1e-183,
    1e-182, 1e-181, 1e-180, 1e-179, 1e-178, 1e-177, 1e-176, 1e-175, 1e-174,
    1e-173, 1e-172, 1e-171, 1e-170, 1e-169, 1e-168, 1e-167, 1e-166, 1e-165,
    1e-164, 1e-163, 1e-162, 1e-161, 1e-160, 1e-159, 1e-158, 1e-157, 1e-156,
    1e-155, 1e-154, 1e-153, 1e-152, 1e-151, 1e-150, 1e-149, 1e-148, 1e-147,
    1e-146, 1e-145, 1e-144, 1e-143, 1e-142, 1e-141, 1e-140, 1e-139, 1e-138,
    1e-137, 1e-136, 1e-135, 1e-134, 1e-133, 1e-132, 1e-131, 1e-130, 1e-129,
    1e-128, 1e-127, 1e-126, 1e-125, 1e-124, 1e-123, 1e-122, 1e-121, 1e-120,
    1e-119, 1e-118, 1e-117, 1e-116, 1e-115, 1e-114, 1e-113, 1e-112, 1e-111,
    1e-110, 1e-109, 1e-108, 1e-107, 1e-106, 1e-105, 1e-104, 1e-103, 1e-102,
    1e-101, 1e-100, 1e-99,  1e-98,  1e-97,  1e-96,  1e-95,  1e-94,  1e-93,
    1e-92,  1e-91,  1e-90,  1e-89,  1e-88,  1e-87,  1e-86,  1e-85,  1e-84,
    1e-83,  1e-82,  1e-81,  1e-80,  1e-79,  1e-78,  1e-77,  1e-76,  1e-75,
    1e-74,  1e-73,  1e-72,  1e-71,  1e-70,  1e-69,  1e-68,  1e-67,  1e-66,
    1e-65,  1e-64,  1e-63,  1e-62,  1e-61,  1e-60,  1e-59,  1e-58,  1e-57,
    1e-56,  1e-55,  1e-54,  1e-53,  1e-52,  1e-51,  1e-50,  1e-49,  1e-48,
    1e-47,  1e-46,  1e-45,  1e-44,  1e-43,  1e-42,  1e-41,  1e-40,  1e-39,
    1e-38,  1e-37,  1e-36,  1e-35,  1e-34,  1e-33,  1e-32,  1e-31,  1e-30,
    1e-29,  1e-28,  1e-27,  1e-26,  1e-25,  1e-24,  1e-23,  1e-22,  1e-21,
    1e-20,  1e-19,  1e-18,  1e-17,  1e-16,  1e-15,  1e-14,  1e-13,  1e-12,
    1e-11,  1e-10,  1e-9,   1e-8,   1e-7,   1e-6,   1e-5,   1e-4,   1e-3,
    1e-2,   1e-1,   1e0,    1e1,    1e2,    1e3,    1e4,    1e5,    1e6,
    1e7,    1e8,    1e9,    1e10,   1e11,   1e12,   1e13,   1e14,   1e15,
    1e16,   1e17,   1e18,   1e19,   1e20,   1e21,   1e22,   1e23,   1e24,
    1e25,   1e26,   1e27,   1e28,   1e29,   1e30,   1e31,   1e32,   1e33,
    1e34,   1e35,   1e36,   1e37,   1e38,   1e39,   1e40,   1e41,   1e42,
    1e43,   1e44,   1e45,   1e46,   1e47,   1e48,   1e49,   1e50,   1e51,
    1e52,   1e53,   1e54,   1e55,   1e56,   1e57,   1e58,   1e59,   1e60,
    1e61,   1e62,   1e63,   1e64,   1e65,   1e66,   1e67,   1e68,   1e69,
    1e70,   1e71,   1e72,   1e73,   1e74,   1e75,   1e76,   1e77,   1e78,
    1e79,   1e80,   1e81,   1e82,   1e83,   1e84,   1e85,   1e86,   1e87,
    1e88,   1e89,   1e90,   1e91,   1e92,   1e93,   1e94,   1e95,   1e96,
    1e97,   1e98,   1e99,   1e100,  1e101,  1e102,  1e103,  1e104,  1e105,
    1e106,  1e107,  1e108,  1e109,  1e110,  1e111,  1e112,  1e113,  1e114,
    1e115,  1e116,  1e117,  1e118,  1e119,  1e120,  1e121,  1e122,  1e123,
    1e124,  1e125,  1e126,  1e127,  1e128,  1e129,  1e130,  1e131,  1e132,
    1e133,  1e134,  1e135,  1e136,  1e137,  1e138,  1e139,  1e140,  1e141,
    1e142,  1e143,  1e144,  1e145,  1e146,  1e147,  1e148,  1e149,  1e150,
    1e151,  1e152,  1e153,  1e154,  1e155,  1e156,  1e157,  1e158,  1e159,
    1e160,  1e161,  1e162,  1e163,  1e164,  1e165,  1e166,  1e167,  1e168,
    1e169,  1e170,  1e171,  1e172,  1e173,  1e174,  1e175,  1e176,  1e177,
    1e178,  1e179,  1e180,  1e181,  1e182,  1e183,  1e184,  1e185,  1e186,
    1e187,  1e188,  1e189,  1e190,  1e191,  1e192,  1e193,  1e194,  1e195,
    1e196,  1e197,  1e198,  1e199,  1e200,  1e201,  1e202,  1e203,  1e204,
    1e205,  1e206,  1e207,  1e208,  1e209,  1e210,  1e211,  1e212,  1e213,
    1e214,  1e215,  1e216,  1e217,  1e218,  1e219,  1e220,  1e221,  1e222,
    1e223,  1e224,  1e225,  1e226,  1e227,  1e228,  1e229,  1e230,  1e231,
    1e232,  1e233,  1e234,  1e235,  1e236,  1e237,  1e238,  1e239,  1e240,
    1e241,  1e242,  1e243,  1e244,  1e245,  1e246,  1e247,  1e248,  1e249,
    1e250,  1e251,  1e252,  1e253,  1e254,  1e255,  1e256,  1e257,  1e258,
    1e259,  1e260,  1e261,  1e262,  1e263,  1e264,  1e265,  1e266,  1e267,
    1e268,  1e269,  1e270,  1e271,  1e272,  1e273,  1e274,  1e275,  1e276,
    1e277,  1e278,  1e279,  1e280,  1e281,  1e282,  1e283,  1e284,  1e285,
    1e286,  1e287,  1e288,  1e289,  1e290,  1e291,  1e292,  1e293,  1e294,
    1e295,  1e296,  1e297,  1e298,  1e299,  1e300,  1e301,  1e302,  1e303,
    1e304,  1e305,  1e306,  1e307,  1e308};

static inline bool is_integer(char c) {
  return (c >= '0' && c <= '9');
  // this gets compiled to (uint8_t)(c - '0') <= 9 on all decent compilers
}

// We need to check that the character following a zero is valid. This is
// probably frequent and it is hard than it looks. We are building all of this
// just to differentiate between 0x1 (invalid), 0,1 (valid) 0e1 (valid)...
const bool structural_or_whitespace_or_exponent_or_decimal_negated[256] = {
    1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 0, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 0, 1, 1,
    1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1};

really_inline bool
is_not_structural_or_whitespace_or_exponent_or_decimal(unsigned char c) {
  return structural_or_whitespace_or_exponent_or_decimal_negated[c];
}

#define SWAR_NUMBER_PARSING

#ifdef SWAR_NUMBER_PARSING

#ifdef _MSC_VER
// check quickly whether the next 8 chars are made of digits
// at a glance, it looks better than Mula's
// http://0x80.pl/articles/swar-digits-validate.html
static inline bool is_made_of_eight_digits_fast(const char *chars) {
  uint64_t val;
  memcpy(&val, chars, 8);
  // a branchy method might be faster:
  // return (( val & 0xF0F0F0F0F0F0F0F0 ) == 0x3030303030303030)
  //  && (( (val + 0x0606060606060606) & 0xF0F0F0F0F0F0F0F0 ) ==
  //  0x3030303030303030);
  return (((val & 0xF0F0F0F0F0F0F0F0) |
           (((val + 0x0606060606060606) & 0xF0F0F0F0F0F0F0F0) >> 4)) ==
          0x3333333333333333);
}
#else
// this is more efficient apparently than the scalar code above (fewer instructions)
static inline bool is_made_of_eight_digits_fast(const char *chars) {
  __m64 val;
  memcpy(&val, chars, 8);
  __m64 base = _mm_sub_pi8(val,_mm_set1_pi8('0'));
  __m64 basecmp = _mm_subs_pu8(base,_mm_set1_pi8(9));
  return _mm_cvtm64_si64(basecmp) == 0;
}
#endif

static inline uint32_t parse_eight_digits_unrolled(const char *chars) {
  // this actually computes *16* values so we are being wasteful.
  const __m128i ascii0 = _mm_set1_epi8('0');
  const __m128i mul_1_10 =
      _mm_setr_epi8(10, 1, 10, 1, 10, 1, 10, 1, 10, 1, 10, 1, 10, 1, 10, 1);
  const __m128i mul_1_100 = _mm_setr_epi16(100, 1, 100, 1, 100, 1, 100, 1);
  const __m128i mul_1_10000 =
      _mm_setr_epi16(10000, 1, 10000, 1, 10000, 1, 10000, 1);
  const __m128i input = _mm_sub_epi8(_mm_loadu_si128((const __m128i *)chars), ascii0);
  const __m128i t1 = _mm_maddubs_epi16(input, mul_1_10);
  const __m128i t2 = _mm_madd_epi16(t1, mul_1_100);
  const __m128i t3 = _mm_packus_epi32(t2, t2);
  const __m128i t4 = _mm_madd_epi16(t3, mul_1_10000);
  return _mm_cvtsi128_si32(
      t4); // only captures the sum of the first 8 digits, drop the rest
}

#endif

// called by parse_number when we know that the output is a float,
// but where there might be some integer overflow. The trick here is to
// parse using floats from the start.
// Do not call this function directly as it skips some of the checks from
// parse_number
//
// This function will almost never be called!!!
//
// Note: a redesign could avoid this function entirely.
//
static never_inline bool
parse_float(const uint8_t *const buf,
                          ParsedJson &pj, const uint32_t offset,
                          bool found_minus) {
  const char *p = (const char *)(buf + offset);
  bool negative = false;
  if (found_minus) {
    ++p;
    negative = true;
  }
  double i;
  if (*p == '0') { // 0 cannot be followed by an integer
    ++p;
    i = 0;
  } else {
    unsigned char digit = *p - '0';
    i = digit;
    p++;
    while (is_integer(*p)) {
      digit = *p - '0';
      i = 10 * i + digit;
      ++p;
    }
  }
  if ('.' == *p) {
    ++p;
    double fractionalweight = 1;
    if(is_integer(*p)) {
      unsigned char digit = *p - '0';
      ++p;
      fractionalweight *= 0.1;
      i = i + digit * fractionalweight;
    } else {
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false;
    }
    while (is_integer(*p)) {
      unsigned char digit = *p - '0';
      ++p;
      fractionalweight *= 0.1;
      i = i + digit * fractionalweight;
    }
  }
  if (('e' == *p) || ('E' == *p)) {
    ++p;
    bool negexp = false;
    if ('-' == *p) {
      negexp = true;
      ++p;
    } else if ('+' == *p) {
      ++p;
    }
    if (!is_integer(*p)) {
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false;
    }
    unsigned char digit = *p - '0';
    int64_t expnumber = digit; // exponential part
    p++;
    if (is_integer(*p)) {
      digit = *p - '0';
      expnumber = 10 * expnumber + digit;
      ++p;
    }
    if (is_integer(*p)) {
      digit = *p - '0';
      expnumber = 10 * expnumber + digit;
      ++p;
    }
    if (is_integer(*p)) {
      digit = *p - '0';
      expnumber = 10 * expnumber + digit;
      ++p;
    }
    if (is_integer(*p)) {
// we refuse to parse this
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false;
    }
    int exponent = (negexp ? -expnumber : expnumber);
    if ((exponent > 308) || (exponent < -308)) {
// we refuse to parse this
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false;
    }
    i *= power_of_ten[308 + exponent];
  }
  if(is_not_structural_or_whitespace(*p)) {
    return false;
  }
  double d = negative ? -i : i;
  pj.write_tape_double(d);
#ifdef JSON_TEST_NUMBERS // for unit testing
  foundFloat(d, buf + offset);
#endif
  return is_structural_or_whitespace(*p);
}

// called by parse_number when we know that the output is an integer,
// but where there might be some integer overflow.
// we want to catch overflows!
// Do not call this function directly as it skips some of the checks from
// parse_number
//
// This function will almost never be called!!!
//
static never_inline bool parse_large_integer(const uint8_t *const buf,
                                             ParsedJson &pj,
                                             const uint32_t offset,
                                             bool found_minus) {
  const char *p = (const char *)(buf + offset);

  bool negative = false;
  if (found_minus) {
    ++p;
    negative = true;
  }
  uint64_t i;
  if (*p == '0') { // 0 cannot be followed by an integer
    ++p;
    i = 0;
  } else {
    unsigned char digit = *p - '0';
    i = digit;
    p++;
    // the is_made_of_eight_digits_fast routine is unlikely to help here because
    // we rarely see large integer parts like 123456789
    while (is_integer(*p)) {
      digit = *p - '0';
      if (mul_overflow(i, 10, &i)) {
#ifdef JSON_TEST_NUMBERS // for unit testing
        foundInvalidNumber(buf + offset);
#endif
        return false; // overflow
      }
      if (add_overflow(i, digit, &i)) {
#ifdef JSON_TEST_NUMBERS // for unit testing
        foundInvalidNumber(buf + offset);
#endif
        return false; // overflow
      }
      ++p;
    }
  }
  if (negative) {
    if (i > 0x8000000000000000) {
// overflows!
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false; // overflow
    }
  } else {
    if (i >= 0x8000000000000000) {
// overflows!
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false; // overflow
    }
  }
  int64_t signed_answer = negative ? -i : i;
  pj.write_tape_s64(signed_answer);
#ifdef JSON_TEST_NUMBERS // for unit testing
  foundInteger(signed_answer, buf + offset);
#endif
  return is_structural_or_whitespace(*p);
}




// parse the number at buf + offset
// define JSON_TEST_NUMBERS for unit testing
static really_inline bool parse_number(const uint8_t *const buf,
                                       ParsedJson &pj,
                                       const uint32_t offset,
                                       bool found_minus) {
#ifdef SIMDJSON_SKIPNUMBERPARSING // for performance analysis, it is sometimes useful to skip parsing
  pj.write_tape_s64(0); // always write zero
  return true; // always succeeds
#else
  const char *p = (const char *)(buf + offset);
  bool negative = false;
  if (found_minus) {
    ++p;
    negative = true;
    if (!is_integer(*p)) { // a negative sign must be followed by an integer
#ifdef JSON_TEST_NUMBERS   // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false;
    }
  }
  const char *const startdigits = p;

  int64_t i;
  if (*p == '0') { // 0 cannot be followed by an integer
    ++p;
    if (is_not_structural_or_whitespace_or_exponent_or_decimal(*p)) {
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false;
    }
    i = 0;
  } else {
    if (!(is_integer(*p))) { // must start with an integer
#ifdef JSON_TEST_NUMBERS     // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false;
    }
    unsigned char digit = *p - '0';
    i = digit;
    p++;
    // the is_made_of_eight_digits_fast routine is unlikely to help here because
    // we rarely see large integer parts like 123456789
    while (is_integer(*p)) {
      digit = *p - '0';
      i = 10 * i + digit; // might overflow
      ++p;
    }
  }

  int64_t exponent = 0;

  if ('.' == *p) {
    ++p;
    const char *const firstafterperiod = p;
    if(is_integer(*p)) {
      unsigned char digit = *p - '0';
      ++p;
      i = i * 10 + digit;
    } else {
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false;      
    }
#ifdef SWAR_NUMBER_PARSING
    // this helps if we have lots of decimals!
    // this turns out to be frequent enough.
    if (is_made_of_eight_digits_fast(p)) {
      i = i * 100000000 + parse_eight_digits_unrolled(p);
      p += 8;
      // exponent -= 8;
    }
#endif
    while (is_integer(*p)) {
      unsigned char digit = *p - '0';
      ++p;
      i = i * 10 + digit; // in rare cases, this will overflow, but that's ok because we have parse_highprecision_float later.
    }
    exponent = firstafterperiod - p;
  }
  int digitcount = p - startdigits - 1;

  int64_t expnumber = 0; // exponential part
  if (('e' == *p) || ('E' == *p)) {
    ++p;
    bool negexp = false;
    if ('-' == *p) {
      negexp = true;
      ++p;
    } else if ('+' == *p) {
      ++p;
    }
    if (!is_integer(*p)) {
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false;
    }
    unsigned char digit = *p - '0';
    expnumber = digit;
    p++;
    while (is_integer(*p)) {
      digit = *p - '0';
      expnumber = 10 * expnumber + digit;
      ++p;
    }
    if (is_integer(*p)) {
      digit = *p - '0';
      expnumber = 10 * expnumber + digit;
      ++p;
    }
    if (is_integer(*p)) {
      digit = *p - '0';
      expnumber = 10 * expnumber + digit;
      ++p;
    }
    if (is_integer(*p)) {
// we refuse to parse this
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundInvalidNumber(buf + offset);
#endif
      return false;
    }
    exponent += (negexp ? -expnumber : expnumber);
  }
  i = negative ? -i : i;
  if ((exponent != 0) || (expnumber != 0)) {
    if (unlikely(digitcount >= 19)) { // this is uncommon!!!
      // this is almost never going to get called!!!
      // we start anew, going slowly!!!
      return parse_float(buf, pj, offset,
                                       found_minus);
    }
    ///////////
    // We want 0.1e1 to be a float.
    //////////
    if (i == 0) {
      pj.write_tape_double(0.0);
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundFloat(0.0, buf + offset);
#endif
    } else {
      if ((exponent > 308) || (exponent < -308)) {
// we refuse to parse this
#ifdef JSON_TEST_NUMBERS // for unit testing
        foundInvalidNumber(buf + offset);
#endif
        return false;
      }
      double d = i;
      d *= power_of_ten[308 + exponent];
      // d = negative ? -d : d;
      pj.write_tape_double(d);
#ifdef JSON_TEST_NUMBERS // for unit testing
      foundFloat(d, buf + offset);
#endif
    }
  } else {
    if (unlikely(digitcount >= 18)) { // this is uncommon!!!
      return parse_large_integer(buf, pj, offset,
                                 found_minus);
    }
    pj.write_tape_s64(i);
#ifdef JSON_TEST_NUMBERS // for unit testing
    foundInteger(i, buf + offset);
#endif
  }
  return  is_structural_or_whitespace(*p);
#endif // SIMDJSON_SKIPNUMBERPARSING
}

#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/numberparsing.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/stage2_build_tape.h */
#ifndef SIMDJSON_STAGE34_UNIFIED_H
#define SIMDJSON_STAGE34_UNIFIED_H


void init_state_machine();

WARN_UNUSED
bool unified_machine(const uint8_t *buf, size_t len, ParsedJson &pj);

WARN_UNUSED
static inline bool unified_machine(const char *buf, size_t len, ParsedJson &pj) {
    return unified_machine((const uint8_t *)buf,len,pj);
}

#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/stage2_build_tape.h */
/* begin file /Users/lemire/CVS/github/simdjson/include/simdjson/jsonparser.h */
#ifndef SIMDJSON_JSONPARSER_H
#define SIMDJSON_JSONPARSER_H





// Parse a document found in buf, need to preallocate ParsedJson.
// Return false in case of a failure. You can also check validity
// by calling pj.isValid(). The same ParsedJson can be reused for other documents.
//
// If reallocifneeded is true (default) then a temporary buffer is created when needed during processing
// (a copy of the input string is made).
// The input buf should be readable up to buf + len + SIMDJSON_PADDING if reallocifneeded is false,
// all bytes at and after buf + len  are ignored (can be garbage).
WARN_UNUSED
bool json_parse(const uint8_t *buf, size_t len, ParsedJson &pj, bool reallocifneeded = true);

// Parse a document found in buf, need to preallocate ParsedJson.
// Return false in case of a failure. You can also check validity
// by calling pj.isValid(). The same ParsedJson can be reused for other documents.
//
// If reallocifneeded is true (default) then a temporary buffer is created when needed during processing
// (a copy of the input string is made).
// The input buf should be readable up to buf + len + SIMDJSON_PADDING  if reallocifneeded is false,
// all bytes at and after buf + len  are ignored (can be garbage).
WARN_UNUSED
inline bool json_parse(const char * buf, size_t len, ParsedJson &pj, bool reallocifneeded = true) {
  return json_parse((const uint8_t *) buf, len, pj, reallocifneeded);
}

// Parse a document found in buf, need to preallocate ParsedJson.
// Return false in case of a failure. You can also check validity
// by calling pj.isValid(). The same ParsedJson can be reused for other documents.
//
// If reallocifneeded is true (default) then a temporary buffer is created when needed during processing
// (a copy of the input string is made).
// the input s should be readable up to s.data() + s.size() + SIMDJSON_PADDING  if reallocifneeded is false,
// all bytes at and after s.data()+s.size() are ignored (can be garbage).
WARN_UNUSED
inline bool json_parse(const std::string_view &s, ParsedJson &pj, bool reallocifneeded = true) {
  return json_parse(s.data(), s.size(), pj, reallocifneeded);
}


// Build a ParsedJson object. You can check validity
// by calling pj.isValid(). This does the memory allocation needed for ParsedJson.
// If reallocifneeded is true (default) then a temporary buffer is created when needed during processing
// (a copy of the input string is made).
//
// the input buf should be readable up to buf + len + SIMDJSON_PADDING  if reallocifneeded is false,
// all bytes at and after buf + len  are ignored (can be garbage).
WARN_UNUSED
ParsedJson build_parsed_json(const uint8_t *buf, size_t len, bool reallocifneeded = true);

WARN_UNUSED
// Build a ParsedJson object. You can check validity
// by calling pj.isValid(). This does the memory allocation needed for ParsedJson.
// If reallocifneeded is true (default) then a temporary buffer is created when needed during processing
// (a copy of the input string is made).
// The input buf should be readable up to buf + len + SIMDJSON_PADDING if reallocifneeded is false,
// all bytes at and after buf + len  are ignored (can be garbage).
inline ParsedJson build_parsed_json(const char * buf, size_t len, bool reallocifneeded = true) {
  return build_parsed_json((const uint8_t *) buf, len, reallocifneeded);
}

// convenience function
WARN_UNUSED
// Build a ParsedJson object. You can check validity
// by calling pj.isValid(). This does the memory allocation needed for ParsedJson.
// If reallocifneeded is true (default) then a temporary buffer is created when needed during processing
// (a copy of the input string is made).
// The input s should be readable up to s.data() + s.size() + SIMDJSON_PADDING  if reallocifneeded is false,
// all bytes at and after s.data()+s.size() are ignored (can be garbage).
inline ParsedJson build_parsed_json(const std::string_view &s, bool reallocifneeded = true) {
  return build_parsed_json(s.data(), s.size(), reallocifneeded);
}

#endif
/* end file /Users/lemire/CVS/github/simdjson/include/simdjson/jsonparser.h */
